Module sample_items

Module sample_items 

A collection of sample items. Good for writing tests and seeing what item definitions look like.

The reason that there are two stackable items is so that you can test that items with different names do not combine together or any other weird behavior.

Structs

JUNK_INST
A DefaultItemInstance of the junk item for testing slot and inventory management.
SWORD_INST
A DefaultItemInstance of the sword item for testing slot and inventory management.
TORCH_FULL_STACK_INST
A DefaultItemInstance of the torch that has a full stack.
TORCH_INST
A DefaultItemInstance of the torch item for testing slot and inventory management.

Statics

JUNK
A simple stackable item.
SWORD
A simple unstackable item.
TORCH
A simple stackable item.