DefaultSlot

Struct DefaultSlot 

pub struct DefaultSlot<'a, I: Item, II: ItemInstance<I>> {
    pub item_instance: Option<II>,
    pub modified: bool,
    pub phantom: PhantomData<&'a I>,
}
A sample slot struct used for testing.

A significant reduction in boiler plate would come from making your own slot non-generic. For the purpose of an example, I decided that I wanted mine to be generic to prove it was possible if for some reason you need that functionality.

The main thing you probably want to change other than that is the transfer method. some methods like half_stack_split and combine_stack would be pretty useful.

Fields

item_instance: Option<II>modified: boolphantom: PhantomData<&'a I>